#!/bin/sh
export PATH='/sbin:/bin:/usr/sbin:/usr/bin:/usr/games:/usr/local/sbin:/usr/local/bin:/root/bin'
echo 'name: lens
version: 4.12.3
id: lens-4.12.3-dd75b59581eabb79ff1fe96a8499da59
key: lens_HrIy992mtzN5wFUKQZBmkf
license: BSD3
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
synopsis: Lenses, Folds and Traversals
description:
    This package comes \"Batteries Included\" with many useful lenses for the types
    commonly used from the Haskell Platform, and with tools for automatically
    generating lenses and isomorphisms for user-supplied data types.
    .
    The combinators in @Control.Lens@ provide a highly generic toolbox for composing
    families of getters, folds, isomorphisms, traversals, setters and lenses and their
    indexed variants.
    .
    An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.
    .
    An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.
    .
    A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.
    .
    Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.
    .
    More information on the care and feeding of lenses, including a brief tutorial and motivation
    for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.
    .
    A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.
    .
    /Lenses, Folds and Traversals/
    .
    With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:
    .
    .
    <<http://i.imgur.com/ALlbPRa.png>>
    .
    <Hierarchy.png (Local Copy)>
    .
    You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
    use any element of the hierarchy as any type it linked to above it.
    .
    The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
    .
    For instance:
    .
    * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
    .
    * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
    .
    /Minimizing Dependencies/
    .
    If you want to provide lenses and traversals for your own types in your own libraries, then you
    can do so without incurring a dependency on this (or any other) lens package at all.
    .
    /e.g./ for a data type:
    .
    > data Foo a = Foo Int Int a
    .
    You can define lenses such as
    .
    > -- bar :: Lens'\'' (Foo a) Int
    > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
    > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
    .
    > -- quux :: Lens (Foo a) (Foo b) a b
    > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
    > quux f (Foo a b c) = fmap (Foo a b) (f c)
    .
    without the need to use any type that isn'\''t already defined in the @Prelude@.
    .
    And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
    .
    > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
    > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
    > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
    .
    What is provided in this library is a number of stock lenses and traversals for
    common haskell types, a wide array of combinators for working them, and more
    exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses, Generics
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Exception.Lens Control.Lens Control.Lens.At
    Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
    Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
    Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
    Control.Lens.Internal Control.Lens.Internal.Bazaar
    Control.Lens.Internal.ByteString Control.Lens.Internal.Coerce
    Control.Lens.Internal.Context Control.Lens.Internal.Deque
    Control.Lens.Internal.Exception Control.Lens.Internal.FieldTH
    Control.Lens.Internal.PrismTH Control.Lens.Internal.Fold
    Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
    Control.Lens.Internal.Instances Control.Lens.Internal.Iso
    Control.Lens.Internal.Level Control.Lens.Internal.List
    Control.Lens.Internal.Magma Control.Lens.Internal.Prism
    Control.Lens.Internal.Review Control.Lens.Internal.Setter
    Control.Lens.Internal.TH Control.Lens.Internal.Zoom
    Control.Lens.Iso Control.Lens.Lens Control.Lens.Level
    Control.Lens.Operators Control.Lens.Plated Control.Lens.Prism
    Control.Lens.Reified Control.Lens.Review Control.Lens.Setter
    Control.Lens.TH Control.Lens.Traversal Control.Lens.Tuple
    Control.Lens.Type Control.Lens.Wrapped Control.Lens.Zoom
    Control.Monad.Error.Lens Control.Parallel.Strategies.Lens
    Control.Seq.Lens Data.Array.Lens Data.Bits.Lens
    Data.ByteString.Lens Data.ByteString.Strict.Lens
    Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
    Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
    Data.Map.Lens Data.Sequence.Lens Data.Set.Lens Data.Text.Lens
    Data.Text.Strict.Lens Data.Text.Lazy.Lens Data.Tree.Lens
    Data.Typeable.Lens Data.Vector.Lens Data.Vector.Generic.Lens
    Generics.Deriving.Lens GHC.Generics.Lens System.Exit.Lens
    System.FilePath.Lens System.IO.Error.Lens Language.Haskell.TH.Lens
    Numeric.Lens
hidden-modules: Paths_lens
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.10.2/lens-4.12.3
library-dirs: /usr/local/lib/cabal/ghc-7.10.2/lens-4.12.3
              /usr/local/lib
data-dir: /usr/local/share/cabal/ghc-7.10.2/lens-4.12.3
hs-libraries: HSlens-4.12.3-HrIy992mtzN5wFUKQZBmkf
include-dirs: /usr/local/include
depends:
    array-0.5.1.0-aabf9daaf6d89a89ffdaf632a0eb259e
    base-4.8.1.0-9cc67f4e5e6328730727313d0bc5e35f
    base-orphans-0.4.4-61f87fbe40b70a96b4f01742198bd89e
    bifunctors-5-fa8b912da4cd7594f47f3ba4070d7485
    bytestring-0.10.6.0-4bad3e0db8dcda038eec8bfd6aea32b3
    comonad-4.2.7.2-f146eb98b8872f5e90a1b965d785c7e6
    containers-0.5.6.2-fa9a4462de473ca3ca1d565cbe6dba33
    contravariant-1.3.2-5dbdae56cc3bf475292a5c2f57cdad11
    distributive-0.4.4-1254ec357618fb29ffd170a9b195cbc3
    exceptions-0.8.0.2-ee397d4a2d409d9e05e24555c5fafbec
    filepath-1.4.0.0-84bda675ba63f9b1a4b3fb9597f70f12
    free-4.12.1-c8b0247cb2e1c910ff2b7811aa02a68a
    ghc-prim-0.4.0.0-2dabcc93617d9a564f2855dd307d7dfb
    hashable-1.2.3.3-c9c80f60fec1c2bfec8f21d0ecd5aacc
    kan-extensions-4.2.2-1d13e7f4943f322f16e3c3e83803ee74
    mtl-2.2.1-6281cd9698784dbc328cef3b013b905d
    parallel-3.2.0.6-7fc1c74ef4215a71c3a5b51007178df6
    profunctors-5.1.1-962fe2984a1f8de459d52917c662cd99
    reflection-2-651cc7a2d4334bc9f02c21763d00fe25
    semigroupoids-5.0.0.3-4c97072519bdc1a3bed5d8c0d81e9f43
    semigroups-0.16.2.2-d219c9202cd1ff8b5079fa0cf0161390
    tagged-0.8.1-06e1b55aa91a737b7f8f4584fc92dcf3
    template-haskell-2.10.0.0-50be769ad8939d8e8caca364b0b694f2
    text-1.2.1.3-6b3e1cbb2a57ec42cb19d113292b56f4
    transformers-0.4.2.0-1c92f7031c1e04e17d9abe73932eb485
    transformers-compat-0.4.0.4-3ca5cbcec233c17da785d5f27705643c
    unordered-containers-0.2.5.1-335583f000f0fa5722ec79c17794446a
    vector-0.10.12.3-27897745aebd646b98c12ed0d61390a9
    void-0.7-8507b99cf37d960f269006aa7badbcfb
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.10.2/lens-4.12.3/html/lens.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.10.2/lens-4.12.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
